=======================================
BCJ(Branch-Call-Jump) filter for python
=======================================

.. image:: https://badge.fury.io/py/bcj-cffi.svg
  :target: https://badge.fury.io/py/bcj-cffi

.. image:: https://github.com/miurahr/bcj-cffi/workflows/Run%20Tox%20tests/badge.svg
  :target: https://github.com/miurahr/bcj-cffi/actions

.. image:: https://coveralls.io/repos/github/miurahr/bcj-cffi/badge.svg?branch=main
  :target: https://coveralls.io/github/miurahr/bcj-cffi?branch=main


In data compression, BCJ, short for Branch-Call-Jump, refers to a technique that improves the compression of
machine code of executable binaries by replacing relative branch addresses with absolute ones.
This allows a LZMA compressor to identify duplicate targets and archive higher compression rate.

BCJ is used in 7-zip compression utility as default filter for executable binaries.

bcj-cffi is a python bindings with BCJ implementation by C language.
The C codes are derived from p7zip, portable 7-zip implementation.
bcj-cffi support Intel/Amd x86/x86_64, Arm/Arm64, ArmThumb, Sparc, PPC, and IA64.


Development status
==================

A development status is considered as `Beta` state.


Installation
============

As usual, you can install bcj-cffi using python standard pip command.

.. code-block::

    pip install bcj-cffi


License
=======

* Copyright (C) 2020,2021 Hiroshi Miura

* 7-Zip Copyright (C) 1999-2010 Igor Pavlov
* LZMA SDK Copyright (C) 1999-2010 Igor Pavlov

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301  USA
